componenttools.get_leftmost_components_with_prolated_duration_at_most
=====================================================================

.. autofunction:: abjad.tools.componenttools.get_leftmost_components_with_prolated_duration_at_most.get_leftmost_components_with_prolated_duration_at_most
